## 1.16.21.20241009 (2024-10-09)

Allowlist `six.create_bound_method.__code__` (Fix daily test failure) (#12759)

## 1.16.21.20240513 (2024-05-13)

Replace types._Cell with types.CellType (#11904)

Closes #11901

## 1.16.21.20240425 (2024-04-25)

Introduce SupportsContainsAndGetItem (#11827)

## 1.16.21.20240311 (2024-03-11)

Use PEP 570 syntax in third party stubs (#11554)

## 1.16.21.20240310 (2024-03-10)

Bump mypy to 1.9, add to json.encoder, small fixups (#11549)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 1.16.21.20240301 (2024-03-01)

Enable nearly all pyupgrade rules (except on test cases) (#11499)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 1.16.21.20240106 (2024-01-06)

Update typing_extensions imports in third-party stubs (#11245)

## 1.16.21.9 (2023-07-20)

Add an upstream_repository field to METADATA.toml (#10487)

Closes: #10478

## 1.16.21.8 (2023-03-28)

Add defaults for third-party stubs Q-T (#9959)

## 1.16.21.7 (2023-03-08)

Replace `object | None` with `object` (#9857)

All types, including `None`, are a subtype of `object`, so `None` is redundant in the union `object | None`.

## 1.16.21.6 (2023-02-22)

Update `Unused` parameters in `stubs/` (#9704)

* Update _Unused TypeAlias

* Update `object | None` params

* Replace unused `object` parameters with `Unused` alias

## 1.16.21.5 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 1.16.21.4 (2022-11-18)

Mark `six` as completed (#9221)

## 1.16.21.3 (2022-11-12)

Fix usage of byte2int with bytes (#9152)

## 1.16.21.2 (2022-11-10)

Improve accuracy of `six` byte index methods (#9117)

## 1.16.21.1 (2022-11-03)

Update pyright to 1.1.278 (#9077)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 1.16.21 (2022-09-27)

Bump mypy to 0.981 (#8796)

## 1.16.20 (2022-09-25)

six: Remove unused `__future__` import (#8790)

## 1.16.19 (2022-08-23)

`six`: Fix incorrect `type[type[Any]]` annotation (#8599)

Mypy will (correctly, I think) start flagging `type[type[Any]]` as an illegal annotation when mypy 0.980 comes out. Let's fix it now, before it comes out.

## 1.16.18 (2022-07-12)

Import `Match` and `Pattern` from `re`, not `typing` (#8277)

## 1.16.17 (2022-07-04)

Third-party stubs: audit more `Callable[<parameters>, Any]` annotations (#8233)

## 1.16.16 (2022-06-13)

Use `_typeshed.IdentityFunction` more consistently (#8063)

## 1.16.15 (2022-04-13)

Add back six.moves.http_cookies.Morsel (#7617)

## 1.16.14 (2022-04-13)

Add back six.moves.configparser.Error (#7616)

## 1.16.13 (2022-04-12)

Add missing definitions to six.moves.http_client (#7615)

These were removed as a side-effect of #7327, which added
`__all__` to `http.client`. I checked that all the definitions
are present at runtime via `six.moves.http_client`.

## 1.16.12 (2022-03-09)

Remove Python 2 support from some third-party distributions (#7466)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 1.16.11 (2022-03-01)

Add six.create_bound_method dunders to allowlist (#7409)

Closes: #7404

## 1.16.10 (2022-01-19)

Use PEP 585 syntax in Python 2, `protobuf` & `_ast` stubs, where possible (#6949)

## 1.16.9 (2022-01-08)

Use lowercase `type` everywhere (#6853)

## 1.16.7 (2022-01-03)

Add six.moves.copyreg six stubs (#6793)

## 1.16.6 (2021-12-28)

Use PEP 585 syntax wherever possible (#6717)

## 1.16.5 (2021-12-27)

Enable stubtest for six (#6699)

## 1.16.4 (2021-12-25)

Add a 'stubtest' flag to METADATA.toml (#6687)

Co-authored-by: Akuli <akuviljanen17@gmail.com>

## 1.16.3 (2021-11-28)

dummy_thread/ing: remove in 3.9 (#6408)

https://bugs.python.org/issue37312

## 1.16.2 (2021-10-12)

Add star to all non-0.1 versions (#6146)

